@@ -32,7 +32,7 @@ class FanoutPublisher(PluginBase):
 
     def pre_receive(self, alert):
 
-        pass
+        return alert
 
     def post_receive(self, alert):
 
